Struct objc2_speech::SFSpeechRecognizer
source · #[repr(C)]pub struct SFSpeechRecognizer { /* private fields */ }Available on crate feature
SFSpeechRecognizer only.Implementations
sourceimpl SFSpeechRecognizer
impl SFSpeechRecognizer
pub unsafe fn supportedLocales() -> Retained<NSSet<NSLocale>>
pub unsafe fn requestAuthorization( handler: &Block<dyn Fn(SFSpeechRecognizerAuthorizationStatus)> )
Available on crate feature
block2 only.pub unsafe fn init(this: Allocated<Self>) -> Option<Retained<Self>>
pub unsafe fn initWithLocale( this: Allocated<Self>, locale: &NSLocale ) -> Option<Retained<Self>>
pub unsafe fn isAvailable(&self) -> bool
pub unsafe fn locale(&self) -> Retained<NSLocale>
pub unsafe fn supportsOnDeviceRecognition(&self) -> bool
pub unsafe fn setSupportsOnDeviceRecognition( &self, supports_on_device_recognition: bool )
pub unsafe fn delegate( &self ) -> Option<Retained<ProtocolObject<dyn SFSpeechRecognizerDelegate>>>
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn SFSpeechRecognizerDelegate>> )
pub unsafe fn defaultTaskHint(&self) -> SFSpeechRecognitionTaskHint
Available on crate feature
SFSpeechRecognitionTaskHint only.pub unsafe fn setDefaultTaskHint( &self, default_task_hint: SFSpeechRecognitionTaskHint )
Available on crate feature
SFSpeechRecognitionTaskHint only.pub unsafe fn recognitionTaskWithRequest_resultHandler( &self, request: &SFSpeechRecognitionRequest, result_handler: &Block<dyn Fn(*mut SFSpeechRecognitionResult, *mut NSError)> ) -> Retained<SFSpeechRecognitionTask>
Available on crate features
SFSpeechRecognitionRequest and SFSpeechRecognitionResult and SFSpeechRecognitionTask and block2 only.pub unsafe fn recognitionTaskWithRequest_delegate( &self, request: &SFSpeechRecognitionRequest, delegate: &ProtocolObject<dyn SFSpeechRecognitionTaskDelegate> ) -> Retained<SFSpeechRecognitionTask>
Available on crate features
SFSpeechRecognitionRequest and SFSpeechRecognitionTask only.pub unsafe fn queue(&self) -> Retained<NSOperationQueue>
pub unsafe fn setQueue(&self, queue: &NSOperationQueue)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.