Struct objc2_speech::SFTranscription
source · #[repr(C)]pub struct SFTranscription { /* private fields */ }Available on crate feature
SFTranscription only.Implementations
sourceimpl SFTranscription
impl SFTranscription
pub unsafe fn formattedString(&self) -> Id<NSString>
pub unsafe fn segments(&self) -> Id<NSArray<SFTranscriptionSegment>>
Available on crate feature
SFTranscriptionSegment only.pub unsafe fn speakingRate(&self) -> c_double
👎Deprecated: speakingRate is moved to SFSpeechRecognitionMetadata
pub unsafe fn averagePauseDuration(&self) -> NSTimeInterval
👎Deprecated: averagePauseDuration is moved to SFSpeechRecognitionMetadata
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.