pub struct SFTranscriptionSegment { /* private fields */ }SFTranscriptionSegment only.Expand description
A discrete part of an entire transcription, as identified by the speech recognizer.
Use SFTranscriptionSegment to get details about a part of an overall SFTranscription. An SFTranscriptionSegment represents an utterance, which is a vocalized word or group of words that represent a single meaning to the speech recognizer (SFSpeechRecognizer).
You don’t create transcription object segments directly. Instead, you access them from a transcription’s SFTranscription/segments property.
A transcription segment includes the following information:
- The text of the utterance, plus any alternative interpretations of the spoken word.
- The character range of the segment within the
SFTranscription/formattedStringof its parentSFTranscription. - A
confidencevalue, indicating how likely it is that the specified string matches the audible speech. - A
timestampanddurationvalue, indicating the position of the segment within the provided audio stream.
See also Apple’s documentation
Implementations
Sourceimpl SFTranscriptionSegment
impl SFTranscriptionSegment
Sourcepub unsafe fn substring(&self) -> Retained<NSString>
pub unsafe fn substring(&self) -> Retained<NSString>
The string representation of the utterance in the transcription segment.
Sourcepub unsafe fn substringRange(&self) -> NSRange
pub unsafe fn substringRange(&self) -> NSRange
The range information for the transcription segment’s substring, relative to the overall transcription.
Use the range information to find the position of the segment within the SFTranscription/formattedString property of the SFTranscription object containing this segment.
Sourcepub unsafe fn timestamp(&self) -> NSTimeInterval
pub unsafe fn timestamp(&self) -> NSTimeInterval
The start time of the segment in the processed audio stream.
The timestamp is the number of seconds between the beginning of the audio content and when the user spoke the word represented by the segment. For example, if the user said the word “time” one second into the transcription “What time is it”, the timestamp would be equal to 1.0.
Sourcepub unsafe fn duration(&self) -> NSTimeInterval
pub unsafe fn duration(&self) -> NSTimeInterval
The number of seconds it took for the user to speak the utterance represented by the segment.
The duration contains the number of seconds it took for the user to speak the one or more words (utterance) represented by the segment. For example, the SFSpeechRecognizer sets duration to 0.6 if the user took 0.6 seconds to say “time” in the transcription of “What time is it?".
Sourcepub unsafe fn confidence(&self) -> c_float
pub unsafe fn confidence(&self) -> c_float
The level of confidence the speech recognizer has in its recognition of the speech transcribed for the segment.
This property reflects the overall confidence in the recognition of the entire phrase. The value is 0 if there was no recognition, and it is closer to 1 when there is a high certainty that a transcription matches the user’s speech exactly. For example, a confidence value of 0.94 represents a very high confidence level, and is more likely to be correct than a transcription with a confidence value of 0.72.
Sourcepub unsafe fn alternativeSubstrings(&self) -> Retained<NSArray<NSString>>
pub unsafe fn alternativeSubstrings(&self) -> Retained<NSArray<NSString>>
An array of alternate interpretations of the utterance in the transcription segment.
Sourcepub unsafe fn voiceAnalytics(&self) -> Option<Retained<SFVoiceAnalytics>>
👎Deprecated: voiceAnalytics is moved to SFSpeechRecognitionMetadata
Available on crate feature SFVoiceAnalytics only.
pub unsafe fn voiceAnalytics(&self) -> Option<Retained<SFVoiceAnalytics>>
voiceAnalytics is moved to SFSpeechRecognitionMetadata
SFVoiceAnalytics only.An analysis of the transcription segment’s vocal properties.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
this is difficult to use correctly, use Ivar::load instead.
Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for SFTranscriptionSegment
impl AsRef<AnyObject> for SFTranscriptionSegment
Sourceimpl AsRef<NSObject> for SFTranscriptionSegment
impl AsRef<NSObject> for SFTranscriptionSegment
Sourceimpl Borrow<AnyObject> for SFTranscriptionSegment
impl Borrow<AnyObject> for SFTranscriptionSegment
Sourceimpl Borrow<NSObject> for SFTranscriptionSegment
impl Borrow<NSObject> for SFTranscriptionSegment
Sourceimpl ClassType for SFTranscriptionSegment
impl ClassType for SFTranscriptionSegment
Sourceconst NAME: &'static str = "SFTranscriptionSegment"
const NAME: &'static str = "SFTranscriptionSegment"
Sourcetype ThreadKind = <<SFTranscriptionSegment as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<SFTranscriptionSegment as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for SFTranscriptionSegment
impl CopyingHelper for SFTranscriptionSegment
Sourcetype Result = SFTranscriptionSegment
type Result = SFTranscriptionSegment
Self if the type has no
immutable counterpart. Read moreSourceimpl Debug for SFTranscriptionSegment
impl Debug for SFTranscriptionSegment
Sourceimpl Deref for SFTranscriptionSegment
impl Deref for SFTranscriptionSegment
Sourceimpl Hash for SFTranscriptionSegment
impl Hash for SFTranscriptionSegment
Sourceimpl Message for SFTranscriptionSegment
impl Message for SFTranscriptionSegment
Sourceimpl NSCopying for SFTranscriptionSegment
impl NSCopying for SFTranscriptionSegment
Sourceimpl NSObjectProtocol for SFTranscriptionSegment
impl NSObjectProtocol for SFTranscriptionSegment
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
use isKindOfClass directly, or cast your objects with AnyObject::downcast_ref