#[repr(C)]pub struct SFSpeechAudioBufferRecognitionRequest { /* private fields */ }SFSpeechRecognitionRequest only.Expand description
Implementations
Sourceimpl SFSpeechAudioBufferRecognitionRequest
impl SFSpeechAudioBufferRecognitionRequest
pub unsafe fn nativeAudioFormat(&self) -> Retained<AVAudioFormat>
objc2-avf-audio only.pub unsafe fn appendAudioPCMBuffer(&self, audio_pcm_buffer: &AVAudioPCMBuffer)
objc2-avf-audio only.pub unsafe fn appendAudioSampleBuffer(&self, sample_buffer: &CMSampleBuffer)
objc2-core-media only.pub unsafe fn endAudio(&self)
Methods from Deref<Target = SFSpeechRecognitionRequest>
pub unsafe fn taskHint(&self) -> SFSpeechRecognitionTaskHint
SFSpeechRecognitionTaskHint only.Sourcepub unsafe fn setTaskHint(&self, task_hint: SFSpeechRecognitionTaskHint)
Available on crate feature SFSpeechRecognitionTaskHint only.
pub unsafe fn setTaskHint(&self, task_hint: SFSpeechRecognitionTaskHint)
SFSpeechRecognitionTaskHint only.Setter for taskHint.
pub unsafe fn shouldReportPartialResults(&self) -> bool
Sourcepub unsafe fn setShouldReportPartialResults(
&self,
should_report_partial_results: bool,
)
pub unsafe fn setShouldReportPartialResults( &self, should_report_partial_results: bool, )
Setter for shouldReportPartialResults.
pub unsafe fn contextualStrings(&self) -> Retained<NSArray<NSString>>
Sourcepub unsafe fn setContextualStrings(
&self,
contextual_strings: &NSArray<NSString>,
)
pub unsafe fn setContextualStrings( &self, contextual_strings: &NSArray<NSString>, )
Setter for contextualStrings.
pub unsafe fn interactionIdentifier(&self) -> Option<Retained<NSString>>
Sourcepub unsafe fn setInteractionIdentifier(
&self,
interaction_identifier: Option<&NSString>,
)
👎Deprecated: Not used anymore
pub unsafe fn setInteractionIdentifier( &self, interaction_identifier: Option<&NSString>, )
Setter for interactionIdentifier.
pub unsafe fn requiresOnDeviceRecognition(&self) -> bool
Sourcepub unsafe fn setRequiresOnDeviceRecognition(
&self,
requires_on_device_recognition: bool,
)
pub unsafe fn setRequiresOnDeviceRecognition( &self, requires_on_device_recognition: bool, )
Setter for requiresOnDeviceRecognition.
pub unsafe fn addsPunctuation(&self) -> bool
Sourcepub unsafe fn setAddsPunctuation(&self, adds_punctuation: bool)
pub unsafe fn setAddsPunctuation(&self, adds_punctuation: bool)
Setter for addsPunctuation.
pub unsafe fn customizedLanguageModel( &self, ) -> Option<Retained<SFSpeechLanguageModelConfiguration>>
SFSpeechLanguageModel only.Sourcepub unsafe fn setCustomizedLanguageModel(
&self,
customized_language_model: Option<&SFSpeechLanguageModelConfiguration>,
)
Available on crate feature SFSpeechLanguageModel only.
pub unsafe fn setCustomizedLanguageModel( &self, customized_language_model: Option<&SFSpeechLanguageModelConfiguration>, )
SFSpeechLanguageModel only.Setter for customizedLanguageModel.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<SFSpeechRecognitionRequest> for SFSpeechAudioBufferRecognitionRequest
impl AsRef<SFSpeechRecognitionRequest> for SFSpeechAudioBufferRecognitionRequest
Sourcefn as_ref(&self) -> &SFSpeechRecognitionRequest
fn as_ref(&self) -> &SFSpeechRecognitionRequest
Sourceimpl Borrow<SFSpeechRecognitionRequest> for SFSpeechAudioBufferRecognitionRequest
impl Borrow<SFSpeechRecognitionRequest> for SFSpeechAudioBufferRecognitionRequest
Sourcefn borrow(&self) -> &SFSpeechRecognitionRequest
fn borrow(&self) -> &SFSpeechRecognitionRequest
Sourceimpl ClassType for SFSpeechAudioBufferRecognitionRequest
impl ClassType for SFSpeechAudioBufferRecognitionRequest
Sourceconst NAME: &'static str = "SFSpeechAudioBufferRecognitionRequest"
const NAME: &'static str = "SFSpeechAudioBufferRecognitionRequest"
Sourcetype Super = SFSpeechRecognitionRequest
type Super = SFSpeechRecognitionRequest
Sourcetype ThreadKind = <<SFSpeechAudioBufferRecognitionRequest as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<SFSpeechAudioBufferRecognitionRequest as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl NSObjectProtocol for SFSpeechAudioBufferRecognitionRequest
impl NSObjectProtocol for SFSpeechAudioBufferRecognitionRequest
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref