#[repr(C)]pub struct SFSpeechAudioBufferRecognitionRequest { /* private fields */ }Available on crate feature
SFSpeechRecognitionRequest only.Implementations
Methods from Deref<Target = SFSpeechRecognitionRequest>
pub unsafe fn taskHint(&self) -> SFSpeechRecognitionTaskHint
Available on crate feature
SFSpeechRecognitionTaskHint only.pub unsafe fn setTaskHint(&self, task_hint: SFSpeechRecognitionTaskHint)
Available on crate feature
SFSpeechRecognitionTaskHint only.pub unsafe fn shouldReportPartialResults(&self) -> bool
pub unsafe fn setShouldReportPartialResults( &self, should_report_partial_results: bool )
pub unsafe fn contextualStrings(&self) -> Id<NSArray<NSString>>
pub unsafe fn setContextualStrings( &self, contextual_strings: &NSArray<NSString> )
pub unsafe fn interactionIdentifier(&self) -> Option<Id<NSString>>
👎Deprecated: Not used anymore
pub unsafe fn setInteractionIdentifier( &self, interaction_identifier: Option<&NSString> )
👎Deprecated: Not used anymore
pub unsafe fn requiresOnDeviceRecognition(&self) -> bool
pub unsafe fn setRequiresOnDeviceRecognition( &self, requires_on_device_recognition: bool )
pub unsafe fn addsPunctuation(&self) -> bool
pub unsafe fn setAddsPunctuation(&self, adds_punctuation: bool)
pub unsafe fn customizedLanguageModel( &self ) -> Option<Id<SFSpeechLanguageModelConfiguration>>
Available on crate feature
SFSpeechLanguageModel only.pub unsafe fn setCustomizedLanguageModel( &self, customized_language_model: Option<&SFSpeechLanguageModelConfiguration> )
Available on crate feature
SFSpeechLanguageModel only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.